@@ -1,5 +1,5 @@
 /*
- * $Id: $
+ * $Id: _deHTMLxs.c,v 1.2 2005/06/10 23:30:31 rsoderberg Exp $
  */
 
 #ifdef DEBUG_PRINT
@@ -177,12 +177,13 @@ char *html_strip(char *s, char *text) {
 		    break;
 
 		case '&':
-		    *t++ = html_tagxlat(&s);
+		    if (t != NULL)
+			*t++ = html_tagxlat(&s);
 		    break;
 
 		default:
 		valid:
-		    if (!tag)
+		    if (!tag && t != NULL)
 			*t++ = c;
 		    break;
 	    }
