@@ -6,7 +6,7 @@
 ## This code is free software; you can redistribute it and/or modify
 ## it under the same terms as Perl itself.
 ##
-## $Id: Agent.pm,v 1.76 2004/12/03 21:45:58 vipul Exp $
+## $Id: Agent.pm,v 1.79 2005/06/16 19:45:58 rsoderberg Exp $
 
 package Razor2::Client::Agent;
 
@@ -15,6 +15,8 @@ use strict;
 use Getopt::Long; 
 use IO::File;
 
+use Razor2::String qw(fisher_yates_shuffle);
+
 use base qw(Razor2::Client::Core);
 use base qw(Razor2::Client::Config);
 use base qw(Razor2::Logger);
@@ -28,6 +30,7 @@ $PROTOCOL = $Razor2::Client::Version::PROTOCOL;
 $VERSION  = $Razor2::Client::Version::VERSION;
 
 
+
 sub new {
     my ($class, $breed) = @_;
 
@@ -46,7 +49,8 @@ sub new {
     foreach (@valid_program_names) { $breed =~ /$_$/ and $ok = $_; }
     unless ($ok) {
         if ($breed =~ /razor-client$/) {
-            create_symlinks(@valid_program_names);
+            # We no longer create symlinks, but for backwards compatibility
+            # return success.
             exit 0;
         }
         die "Invalid program name, must be one of: @valid_program_names\n";
@@ -130,9 +134,6 @@ sub do_conf {
     $self->logobj(15,"cmd-line options", $self->{opt});
     $self->{preproc}->{rm}->{log} = $self->{logref};
 
-    #my $chadrules;  # test warning
-    #$self->logobj(3,"warn on this $chadrules");
-
     # creates razorhome, and sets $self->{razorhome} if successful
     return $self->errprefix("Could not create 'razorhome'") unless $self->create_home_conf(); 
     $self->compute_identity;
@@ -214,7 +215,6 @@ sub log {
     if ($self->{logref}) {
         return  $self->{logref}->log($level, $msg);
     } elsif ($self->{opt}->{debug}) {
-    #} else {
         print " Razor-Log: $msg\n" if $self->{opt}->{debug};
     }
 }
@@ -896,27 +896,6 @@ sub logerr {
 
 
 
-sub create_symlinks {
-    my @progs = @_;
-    my $bdir = $0 =~ /^\// ? $0 : "$ENV{PWD}/$0";
-    $bdir =~ s|/([^/]+)$||;
-    foreach (@progs) {
-        if (-e "$bdir/$_") {
-            next if -l "$bdir/$_";           # unless a symlink, prolly razor2
-            rename ("$bdir/$_", "$bdir/$_.v1")  # rename razor1 
-        }
-        print "Creating symlink $1 <== $bdir/$_\n";
-        symlink($1, "$bdir/$_") if $^O ne 'VMS';
-        
-        # Do VMS specific stuff.
-        if ($^O eq 'VMS' ) {
-            my ($disk, $dir, $file) = File::Spec->splitpath($1);
-            File::Copy::copy($1,File::Spec->catpath($disk,$dir,"$_"));
-        }
-    }
-}
-
-
 # see nextserver() for explanation of how data is stored
 #
 sub get_server_info {
@@ -958,6 +937,11 @@ sub readservers {
                 $self->{conf}->{"listfile_$lf"});
         }
     }
+    foreach my $lf (qw(discovery nomination catalogue)) {
+        next unless ref($self->{s}->{$lf});
+        next unless @{$self->{s}->{$lf}} > 1;
+        fisher_yates_shuffle($self->{s}->{$lf});
+    }
     if ($self->{breed} =~ /^check/) {
         $self->{s}->{list} = $self->{s}->{catalogue};
         $self->{s}->{listfile} = $self->{conf}->{listfile_catalogue}; # for discovery()
