@@ -6,7 +6,7 @@
 ## This code is free software; you can redistribute it and/or modify
 ## it under the same terms as Perl itself.
 ##
-## $Id: Core.pm,v 1.76 2004/12/03 21:44:56 vipul Exp $
+## $Id: Core.pm,v 1.81 2005/06/13 23:49:42 rsoderberg Exp $
 
 package Razor2::Client::Core;
 
@@ -29,7 +29,7 @@ package Razor2::Client::Core;
                           fisher_yates_shuffle);
 
 
-($VERSION) = do { my @r = (q$Revision: 1.76 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+($VERSION) = do { my @r = (q$Revision: 1.81 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 $PROTOCOL = $Razor2::Client::Version::PROTOCOL; 
 
 
@@ -202,44 +202,7 @@ sub bootstrap_discovery {
         }
     } 
 
-    my $zone = $self->{conf}->{razorzone};
-    $self->log(5,"Finding Discovery Servers via DNS in the $zone zone");
-
-    my $resolver = $self->load_at_runtime("Net::DNS::Resolver")
-        or return $self->errprefix("bootstrap_discovery");
-
-    my @list;
-
-    BUILDLIST: 
-    for ( 'a'..'z' ) { 
-        my $query = $resolver->query ($_.'.'.$zone);
-        my $rr; next BUILDLIST unless $query;
-        foreach $rr ($query->answer) { 
-            my $pushed = 0;
-            if ($rr->type eq "A") { 
-                if ($rr->address =~ m/^(\d+\.\d+\.\d+\.\d+)$/) {
-                    push @list, $1; 
-                    $pushed = 1;
-                }
-            } elsif ($rr->type eq "CNAME") { 
-                if ($rr->cname eq 'list.terminator') { 
-                    pop @list if $pushed;
-                    last BUILDLIST;
-                } elsif ($rr->cname eq "skip") { 
-                    pop @list if $pushed;
-                    next BUILDLIST;
-                }
-            }
-        }
-    }
-    $self->{done_bootstrap} = 1;
-
-    $self->log(6,"Found ". scalar(@list) ." Discovery Servers via DNS in the $zone zone");
-
-    return $self->error("No Razor Discovery servers available at this time")
-        unless scalar(@list);
-
-    $self->{s}->{discovery} = \@list;
+    $self->{s}->{discovery} = [ $self->{conf}->{razordiscovery} ];
     push @{$self->{s}->{modified_lst}}, "discovery";
     return 1;
 }
@@ -346,37 +309,16 @@ sub discover {
     #return $self->error("Could not get valid info from Discovery Servers")
     #    unless @list;
     unless (@list) { 
+        if ($self->{force_bootstrap_discovery}) {
+            return $self->error("Bootstrap discovery failed. Giving up.");
+        }
         $self->log(5, "Couldn't talk to discovery servers.  Will force a bootstrap...");
         $self->{force_bootstrap_discovery} = 1;
         return $self->error("Bootstrap discovery failed. Giving up.") unless $self->bootstrap_discovery();
         return $self->discover();
     }
 
-        # $self->logobj(11,"checking ping times for servers", \@list);
-
-    if ($self->{conf}->{sort_by_distance}) { 
-        # sort @list by ping time
-        #
-        my $pinger = $self->load_at_runtime("Net::Ping", "new", "'tcp', 4")
-            or return $self->errprefix("discover2");
-
-        my %times; my $timings;
-       
-        for (@list) {
-            $" = ", ";
-            print "Will determine the closest of:\n\t(@list)\n";
-            my $t1 = $self->load_at_runtime("Time::HiRes", "gettimeofday");
-            $pinger->ping($_);
-            my $t2 = $self->load_at_runtime("Time::HiRes", "gettimeofday");
-            $times{$_} = $t2 - $t1;
-        }
-        @list = sort { $times{$a} <=> $times{$b} } keys %times;
-        #for (@list) { $timings .= sprintf ("  %4.1fms %s,", $times{$_}*1000, $_);  }
-        $timings = join( ', ', map {sprintf ("%4.1fms %s", $times{$_}*1000, $_)} @list);
-        $self->log (5,"Sorted (closest first) list of $stype{$querytype} ($querytype) servers & RTTs:$timings");
-    } else { 
-        fisher_yates_shuffle(\@list);
-    }
+    fisher_yates_shuffle(\@list) if @list > 1;
 
     $self->{s}->{$stype{$querytype}} = \@list;
     push @{$self->{s}->{modified_lst}}, $stype{$querytype};
@@ -567,29 +509,6 @@ sub compute_sigs {
             $self->log(8,"mail ". $obj->{id} ." has no subject");
         }
 
-=delete engine 1 code
-
-        #
-        # engine 1 is special case - must be same as razor 1
-        #
-        my ($hdrs, $body) = split /\n\r*\n/, ${$obj->{orig_mail}}, 2;
-        if ($body) {
-            $self->log2file( 16, \$body, "$obj->{id}.before.preproc_vr1" );
-            $obj->{e1}->{body} = \$body;
-            my $cln = $body;
-            $self->{preproc_vr1}->doit(\$cln);
-            $obj->{e1}->{cleaned} = \$cln;
-            $self->log2file( 16, \$cln, "$obj->{id}.after.preproc_vr1" );
-
-            my $sig = $self->compute_engine(1, \$cln );
-            $obj->{e1}->{e1} = $sig;
-            push @printable_sigs, "$obj->{id}  e1: $sig";
-        } else {
-            $self->log(6,"body empty for mail $obj->{id}, skipping eng 1 sig.");
-        }
-
-=cut
-
         # 
         # clean each bodypart, removing if new length is 0 
         #
@@ -622,7 +541,7 @@ sub compute_sigs {
                 $self->log(6,"preproc: mail $objp->{id} went from $olen bytes to 0, erasing");
                 $objp->{skipme} = 1;
                 next;
-	        } elsif (($clen < 128) and ($clnpart =~ /^(Content\S*:[^\n]*\n\r?)+(Content\S*:[^\n]*)?\s*$/s)) {
+            } elsif (($clen < 128) and ($clnpart =~ /^(Content\S*:[^\n]*\n\r?)+(Content\S*:[^\n]*)?\s*$/s)) {
                 $self->log(6,"preproc: mail $objp->{id} seems empty, erasing");
                 $objp->{skipme} = 1;
                 next;
@@ -665,11 +584,7 @@ sub compute_sigs {
                 my $engine_no = $_;
                 my $sig;
 
-                if ($engine_no == 1) { 
-                    
-                    next;   # handled above
-
-                } elsif ($engine_no == 4) { 
+                if ($engine_no == 4) { 
 
                     $sig = $self->compute_engine( 
                             $engine_no, 
@@ -677,21 +592,6 @@ sub compute_sigs {
                             $obj->{ep4} 
                     );  
 
-                } elsif ($engine_no == 5) { 
-
-                    $sig = $self->compute_engine( 
-                            $engine_no, 
-                            $objp->{body}
-                    );  
-
-
-                } elsif ($engine_no == 7) { 
-                    
-                    $sig = $self->compute_engine( 
-                            $engine_no, 
-                            $objp->{body}
-                    );  
-
                 } elsif ($engine_no == 8) { 
                     
                     $sig = $self->compute_engine( 
@@ -699,15 +599,10 @@ sub compute_sigs {
                             $objp->{cleaned_vr8}
                     );  
 
-                } else {  
-
-                    # For nilsimsa and sha1 which are no longer supported
-                    # by the server, and might be removed someday
-
-                    $sig = $self->compute_engine( 
-                            $engine_no, 
-                            $objp->{cleaned}
-                    );  
+                } else {
+                    
+                    # Unsupported signature type, don't calculate.
+                    next;   # handled above
 
                 }
 
